<?php

// ------------ load the textdomain for language-support ------------ //

load_theme_textdomain( 'og-zwanzig', get_template_directory() . '/languages');



// ------------ add WordPress title-tag ------------ //

function og_slug_setup() {
   add_theme_support( 'title-tag' );
}
add_action( 'after_setup_theme', 'og_slug_setup' );


if ( ! function_exists( '_wp_render_title_tag' ) ) :
    function og_render_title() {
?>
<title><?php wp_title( '|', true, 'right' ); ?></title>
<?php
    }
    add_action( 'wp_head', 'og_render_title' );
endif;



// ------------ redirecting a search when there is only one result ------------ //

function theme_show_on_match() {  
    if ( is_search() ) {  
        global $wp_query;  
        if ($wp_query->post_count == 1) {  
            wp_redirect( get_permalink( $wp_query->posts['0']->ID ) );  
        }  
    }  
}
add_action('template_redirect', 'theme_show_on_match');  



// ------------ add theme-customizer-options ------------ //

function og_theme_customizer( $wp_customize ) {


// ------------ add section for basic options ------------ //

	$wp_customize->add_section( 'ZWANZIG_basic', array(
		'title' => __('ZWANZIG - Basic options','og-zwanzig'),
		'priority' => '1'
	) );
	
	// add the settings and the controls

		$wp_customize->add_setting( 'navigation_open', array(
			'default' => 0,
			'sanitize_callback' => 'sanitize_checkbox',
			'type' => 'option',
		) );
		 
		$wp_customize->add_control( 'navigation_open', array(
			'label' => __('The Navigation-bar is open by default','og-zwanzig'),
			'type' => 'checkbox',
			'priority' => '1',
			'section' => 'ZWANZIG_basic',
		) );

		$wp_customize->add_setting( 'sidebar_alignment', array(
			'default' => '0',
			'type' => 'option',
			'sanitize_callback' => 'sanitize_sidebar_alignment',
		) );
		 
		$wp_customize->add_control( 'sidebar_alignment', array(
			'label' => __('Sidebar alignment','og-zwanzig'),
			'section' => 'ZWANZIG_basic',
			'type' => 'select',
			'priority' => '2',
			'choices' => array(
				'0' => __('left (default)','og-zwanzig'),
				'1' => __('right','og-zwanzig'),
			),
		) );

		function sanitize_sidebar_alignment( $input ) {
			$valid = array(
				'0' => __('left (default)','og-zwanzig'),
				'1' => __('right','og-zwanzig'),
			);
 
			if ( array_key_exists( $input, $valid ) ) {
				return $input;
			} else {
				return '';
				}
		}

		$wp_customize->add_setting( 'posts_comments', array(
			'default' => 0,
			'sanitize_callback' => 'sanitize_checkbox',
			'type' => 'option',
		) );
		 
		$wp_customize->add_control( 'posts_comments', array(
			'label' => __('Display number of posts and comments in the theme-credits','og-zwanzig'),
			'type' => 'checkbox',
			'priority' => '3',
			'section' => 'ZWANZIG_basic',
		) );

		$wp_customize->add_setting( 'copyright', array(
			'type' => 'option',
			'sanitize_callback' => 'sanitize_text',
		) );

		$wp_customize->add_control( 'copyright', array(
			'label' => __('Copyright-text','og-zwanzig'),
			'type' => 'text',
			'priority' => '4',
			'section' => 'ZWANZIG_basic',
		) );

		$wp_customize->add_setting( 'google_analytics', array(
			'type' => 'option',
			'sanitize_callback' => 'custom_sanitize_textarea',
		) );

		$wp_customize->add_control( new WP_Customize_Textarea_Control( $wp_customize, 'google_analytics', array(
			'label' => __('Google Analytics Tracking-Code','og-zwanzig'),
			'priority' => '5',
			'section' => 'ZWANZIG_basic',
		) ) );

		$wp_customize->add_setting( 'excerpt_words', array(
			'type' => 'option',
			'sanitize_callback' => 'sanitize_text',
		) );

		$wp_customize->add_control( 'excerpt_words', array(
			'label' => __('Number of words for excerpts','og-zwanzig'),
			'type' => 'text',
			'priority' => '6',
			'section' => 'ZWANZIG_basic',
		) );

		$wp_customize->add_setting( 'excerpt_moretag', array(
			'default' => 0,
			'type' => 'option',
			'sanitize_callback' => 'sanitize_checkbox',
		) );
		 
		$wp_customize->add_control( 'excerpt_moretag', array(
			'label' => __('Excerpts with a more-button','og-zwanzig'),
			'type' => 'checkbox',
			'priority' => '7',
			'section' => 'ZWANZIG_basic',
		) );

		$wp_customize->add_setting( 'searchform', array(
			'default' => 0,
			'type' => 'option',
			'sanitize_callback' => 'sanitize_checkbox',
		) );
		 
		$wp_customize->add_control( 'searchform', array(
			'label' => __('Display a search-form in the top-bar','og-zwanzig'),
			'type' => 'checkbox',
			'priority' => '8',
			'section' => 'ZWANZIG_basic',
		) );

		$wp_customize->add_setting( 'search_archive', array(
			'default' => 0,
			'type' => 'option',
			'sanitize_callback' => 'sanitize_checkbox',
		) );
		 
		$wp_customize->add_control( 'search_archive', array(
			'label' => __('Display a list of the last posts, tags and categories, if there is no search result','og-zwanzig'),
			'type' => 'checkbox',
			'priority' => '9',
			'section' => 'ZWANZIG_basic',
		) );



// ------------ add section for fonts options ------------ //

	$wp_customize->add_section( 'ZWANZIG_fonts', array(
		'title' => __('ZWANZIG - Fonts','og-zwanzig'),
		'priority' => '2'
	) );
	
	// add the settings and the controls

		$wp_customize->add_setting( 'font_size', array(
			'default' => '14px',
			'type' => 'option',
			'sanitize_callback' => 'sanitize_font_size',
		) );
		 
		$wp_customize->add_control( 'font_size', array(
			'label' => __('Default font-size','og-zwanzig'),
			'section' => 'ZWANZIG_fonts',
			'type' => 'select',
			'priority' => '2',
			'choices' => array(
				'12px' => __('12 Pixel','og-zwanzig'),
				'13px' => __('13 Pixel','og-zwanzig'),
				'14px' => __('14 Pixel (default)','og-zwanzig'),
				'15px' => __('15 Pixel','og-zwanzig'),
				'16px' => __('16 Pixel','og-zwanzig'),
			),
		) );

		function sanitize_font_size( $input ) {
			$valid = array(
				'12px' => __('12 Pixel','og-zwanzig'),
				'13px' => __('13 Pixel','og-zwanzig'),
				'14px' => __('14 Pixel (default)','og-zwanzig'),
				'15px' => __('15 Pixel','og-zwanzig'),
				'16px' => __('16 Pixel','og-zwanzig'),
			);
 
			if ( array_key_exists( $input, $valid ) ) {
				return $input;
			} else {
				return '';
				}
		}

		$wp_customize->add_setting( 'font_standard', array(
			'default' => '0',
			'type' => 'option',
			'sanitize_callback' => 'sanitize_font_standard',
		) );
		 
		$wp_customize->add_control( 'font_standard', array(
			'label' => __('Default font','og-zwanzig'),
			'section' => 'ZWANZIG_fonts',
			'type' => 'select',
			'priority' => '3',
			'choices' => array(
				'0' => __('Open Sans (default)','og-zwanzig'),
				'1' => 'Varela Round',
				'2' => 'Source Sans Pro',
				'3' => 'PT Sans',
				'4' => 'Ubuntu',
				'5' => 'Roboto',
				'6' => 'Noto Sans',
				'7' => 'Noto Serif',
				'8' => 'Arial',
				'9' => 'Verdana',
				'10' => 'Tahoma',
				'11' => 'Lucida Sans',
				'12' => 'Georgia',
				'13' => __('Custom','og-zwanzig'),
			),
		) );

		function sanitize_font_standard( $input ) {
			$valid = array(
				'0' => __('Open Sans (default)','og-zwanzig'),
				'1' => 'Varela Round',
				'2' => 'Source Sans Pro',
				'3' => 'PT Sans',
				'4' => 'Ubuntu',
				'5' => 'Roboto',
				'6' => 'Noto Sans',
				'7' => 'Noto Serif',
				'8' => 'Arial',
				'9' => 'Verdana',
				'10' => 'Tahoma',
				'11' => 'Lucida Sans',
				'12' => 'Georgia',
				'13' => __('Custom','og-zwanzig'),
			);
 
			if ( array_key_exists( $input, $valid ) ) {
				return $input;
			} else {
				return '';
				}
		}

		$wp_customize->add_setting( 'font_standard_html', array(
			'type' => 'option',
			'sanitize_callback' => 'custom_sanitize_textarea',
		) );

		$wp_customize->add_control( 'font_standard_html', array(
			'label' => __('HTML-Code (<link href=...>) for custom default font','og-zwanzig'),
			'type' => 'text',
			'priority' => '4',
			'section' => 'ZWANZIG_fonts',
		) );

		$wp_customize->add_setting( 'font_standard_css', array(
			'type' => 'option',
			'sanitize_callback' => 'sanitize_text',
		) );

		$wp_customize->add_control( 'font_standard_css', array(
			'label' => __('CSS-Code (font-family:...;) for custom default font','og-zwanzig'),
			'type' => 'text',
			'priority' => '5',
			'section' => 'ZWANZIG_fonts',
		) );

		$wp_customize->add_setting( 'font_h', array(
			'default' => '0',
			'type' => 'option',
			'sanitize_callback' => 'sanitize_font_h',
		) );
		 
		$wp_customize->add_control( 'font_h', array(
			'label' => __('Default heading-font','og-zwanzig'),
			'section' => 'ZWANZIG_fonts',
			'type' => 'select',
			'priority' => '6',
			'choices' => array(
				'0' => __('Open Sans Condensed (default)','og-zwanzig'),
				'1' => 'Fjalla One',
				'2' => 'Raleway',
				'3' => 'Montserrat',
				'4' => 'Open Sans light',
				'5' => 'Bitter',
				'6' => 'Bree Serif',
				'7' => 'Francois One',
				'8' => 'Lato',
				'9' => 'Arial',
				'10' => 'Verdana',
				'11' => 'Tahoma',
				'12' => 'Lucida Sans',
				'13' => __('Custom','og-zwanzig'),
			),
		) );

		function sanitize_font_h( $input ) {
			$valid = array(
				'0' => __('Open Sans Condensed (default)','og-zwanzig'),
				'1' => 'Fjalla One',
				'2' => 'Raleway',
				'3' => 'Montserrat',
				'4' => 'Open Sans light',
				'5' => 'Bitter',
				'6' => 'Bree Serif',
				'7' => 'Francois One',
				'8' => 'Lato',
				'9' => 'Arial',
				'10' => 'Verdana',
				'11' => 'Tahoma',
				'12' => 'Lucida Sans',
				'13' => __('Custom','og-zwanzig'),
			);
 
			if ( array_key_exists( $input, $valid ) ) {
				return $input;
			} else {
				return '';
				}
		}

		$wp_customize->add_setting( 'font_h_html', array(
			'type' => 'option',
			'sanitize_callback' => 'custom_sanitize_textarea',
		) );

		$wp_customize->add_control( 'font_h_html', array(
			'label' => __('HTML-Code (<link href=...>) for custom heading font','og-zwanzig'),
			'type' => 'text',
			'priority' => '7',
			'section' => 'ZWANZIG_fonts',
		) );

		$wp_customize->add_setting( 'font_h_css', array(
			'type' => 'option',
			'sanitize_callback' => 'sanitize_text',
		) );

		$wp_customize->add_control( 'font_h_css', array(
			'label' => __('CSS-Code (font-family:...;) for custom heading font','og-zwanzig'),
			'type' => 'text',
			'priority' => '8',
			'section' => 'ZWANZIG_fonts',
		) );



// ------------ add section for header-slider ------------ //

	$wp_customize->add_section( 'ZWANZIG_header_slider', array(
		'title' => __('ZWANZIG - Header-slider','og-zwanzig'),
		'description' => __('With the following options you can display an simple article-slider in the header. The slider shows the last five posts with title and post-thumbnail. Be aware that all five posts have a post-thumbnail assigned.','og-zwanzig'),
		'priority' => '2'
	) );

	// add the settings and the controls

		$wp_customize->add_setting( 'header_slider', array(
			'default' => 0,
			'type' => 'option',
			'sanitize_callback' => 'sanitize_checkbox',
		) );
		 
		$wp_customize->add_control( 'header_slider', array(
			'label' => __('Display the header-slider','og-zwanzig'),
			'type' => 'checkbox',
			'priority' => '1',
			'section' => 'ZWANZIG_header_slider',
		) );

		$wp_customize->add_setting( 'header_slider_home', array(
			'default' => 1,
			'type' => 'option',
			'sanitize_callback' => 'sanitize_checkbox',
		) );
		 
		$wp_customize->add_control( 'header_slider_home', array(
			'label' => __('Display the header-slider only on the frontpage','og-zwanzig'),
			'type' => 'checkbox',
			'priority' => '2',
			'section' => 'ZWANZIG_header_slider',
		) );

		$wp_customize->add_setting( 'header_slider_time', array(
			'type' => 'option',
			'sanitize_callback' => 'sanitize_text',
		) );

		$wp_customize->add_control( 'header_slider_time', array(
			'label' => __('Time for a complete iteration in seconds (default 30 seconds)','og-zwanzig'),
			'priority' => '3',
			'section' => 'ZWANZIG_header_slider',
		) );

		$wp_customize->add_setting( 'header_slider_reverse', array(
			'default' => 0,
			'type' => 'option',
			'sanitize_callback' => 'sanitize_checkbox',
		) );
		 
		$wp_customize->add_control( 'header_slider_reverse', array(
			'label' => __('Reverse direction','og-zwanzig'),
			'type' => 'checkbox',
			'priority' => '4',
			'section' => 'ZWANZIG_header_slider',
		) );

		$wp_customize->add_setting( 'header_slider_excerpt', array(
			'default' => 0,
			'type' => 'option',
			'sanitize_callback' => 'sanitize_checkbox',
		) );
		 
		$wp_customize->add_control( 'header_slider_excerpt', array(
			'label' => __('Show a post-preview within the post-title','og-zwanzig'),
			'type' => 'checkbox',
			'priority' => '5',
			'section' => 'ZWANZIG_header_slider',
		) );

		$wp_customize->add_setting( 'header_slider_progressbar', array(
			'default' => 0,
			'type' => 'option',
			'sanitize_callback' => 'sanitize_checkbox',
		) );
		 
		$wp_customize->add_control( 'header_slider_progressbar', array(
			'label' => __('Display a progressbar','og-zwanzig'),
			'type' => 'checkbox',
			'priority' => '6',
			'section' => 'ZWANZIG_header_slider',
		) );

		$wp_customize->add_setting( 'header_slider_border', array(
			'default' => 0,
			'type' => 'option',
			'sanitize_callback' => 'sanitize_checkbox',
		) );
		 
		$wp_customize->add_control( 'header_slider_border', array(
			'label' => __('Display the post-thumbnails with border','og-zwanzig'),
			'type' => 'checkbox',
			'priority' => '7',
			'section' => 'ZWANZIG_header_slider',
		) );

		$wp_customize->add_setting( 'header_slider_responsive', array(
			'default' => 0,
			'type' => 'option',
			'sanitize_callback' => 'sanitize_checkbox',
		) );
		 
		$wp_customize->add_control( 'header_slider_responsive', array(
			'label' => __('Do not display the slider on small resolutions (less than 600 pixel width)','og-zwanzig'),
			'type' => 'checkbox',
			'priority' => '8',
			'section' => 'ZWANZIG_header_slider',
		) );



// ------------ add section for blog-description ------------ //

	$wp_customize->add_section( 'ZWANZIG_blog-description', array(
		'title' => __('ZWANZIG - Blog-description','og-zwanzig'),
		'description' => __('Use the following options to describe you or your blog with a few words. This description will shown in the sidebar.','og-zwanzig'),
		'priority' => '2'
	) );
	
	// add the settings and the controls

		$wp_customize->add_setting( 'blog_description', array(
			'default' => 0,
			'type' => 'option',
			'sanitize_callback' => 'sanitize_checkbox',
		) );
		 
		$wp_customize->add_control( 'blog_description', array(
			'label' => __('Display the blog-description','og-zwanzig'),
			'type' => 'checkbox',
			'priority' => '1',
			'section' => 'ZWANZIG_blog-description',
		) );

		$wp_customize->add_setting( 'blog_description_home', array(
			'type' => 'option',
			'sanitize_callback' => 'sanitize_checkbox',
		) );
		 
		$wp_customize->add_control( 'blog_description_home', array(
			'label' => __('Display the blog-description only on the frontpage','og-zwanzig'),
			'type' => 'checkbox',
			'priority' => '2',
			'section' => 'ZWANZIG_blog-description',
		) );

		$wp_customize->add_setting( 'blog_description_title', array(
			'type' => 'option',
			'sanitize_callback' => 'sanitize_text',
		) );
		
		$wp_customize->add_control( 'blog_description_title', array(
			'label'	=> __( 'Heading for the blog-description', 'og-zwanzig' ),
			'priority' => '3',
			'type' => 'text',
			'section' => 'ZWANZIG_blog-description',
		) );

		$wp_customize->add_setting( 'blog_description_slug', array(
			'type' => 'option',
			'sanitize_callback' => 'sanitize_text',
		) );
		
		$wp_customize->add_control( new WP_Customize_Textarea_Control( $wp_customize, 'blog_description_slug', array(
			'label'	=> __( 'Description (you can use HTML-Tags)', 'og-zwanzig' ),
			'priority' => '4',
			'section' => 'ZWANZIG_blog-description',
		) ) );

		$wp_customize->add_setting( 'blog_description_logo', array(
			'type' => 'option',
			'sanitize_callback' => 'esc_url_raw',
		) );

		$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'blog_description_logo', array(
			'label'   => __('Upload a logo (displayed inside the description-text)','og-zwanzig'),
			'priority' => '5',
			'section' => 'ZWANZIG_blog-description',
		) ) );



// ------------ add a section for logo upload ------------ //

	$wp_customize->add_section( 'ZWANZIG_logo', array(
		'title' => __('ZWANZIG - Logo','og-zwanzig'),
		'description' => __('You can upload your own logo(s). The logos are displayed in the top-bar and the footer','og-zwanzig'),
		'priority' => '2'
	) );
	
	// add the settings and the controls

		$wp_customize->add_setting( 'display_logo_top', array(
			'default' => 0,
			'type' => 'option',
			'sanitize_callback' => 'sanitize_checkbox',
		) );
		 
		$wp_customize->add_control( 'display_logo_top', array(
			'label' => __('Display a logo in the left corner of the top-bar','og-zwanzig'),
			'type' => 'checkbox',
			'priority' => '1',
			'section' => 'ZWANZIG_logo',
		) );

		$wp_customize->add_setting( 'logo_top', array(
			'type' => 'option',
			'sanitize_callback' => 'esc_url_raw',
		) );

		$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'logo_top', array(
			'label'   => __('Logo for the top-bar (displayed max height 40 pixel)','og-zwanzig'),
			'priority' => '2',
			'section' => 'ZWANZIG_logo',
		) ) );

		$wp_customize->add_setting( 'display_logo_footer', array(
			'default' => 0,
			'type' => 'option',
			'sanitize_callback' => 'sanitize_checkbox',
		) );
		 
		$wp_customize->add_control( 'display_logo_footer', array(
			'label' => __('Display a logo in the footer','og-zwanzig'),
			'type' => 'checkbox',
			'priority' => '3',
			'section' => 'ZWANZIG_logo',
		) );

		$wp_customize->add_setting( 'logo_footer', array(
			'type' => 'option',
			'sanitize_callback' => 'esc_url_raw',
		) );

		$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'logo_footer', array(
			'label'   => __('Logo for the footer','og-zwanzig'),
			'priority' => '4',
			'section' => 'ZWANZIG_logo',
		) ) );



// ------------ add a section for post options ------------ //

	$wp_customize->add_section( 'ZWANZIG_posts', array(
		'title' => __('ZWANZIG - Post options','og-zwanzig'),
		'priority' => '3'
	) );

	// add the settings and the controls
			
		$wp_customize->add_setting( 'post_info_author', array(
			'default' => 0,
			'type' => 'option',
			'sanitize_callback' => 'sanitize_checkbox',
		) );
		 
		$wp_customize->add_control( 'post_info_author', array(
			'label' => __('Display name of post-author in the post-informations','og-zwanzig'),
			'type' => 'checkbox',
			'priority' => '1',
			'section' => 'ZWANZIG_posts',
		) );

		$wp_customize->add_setting( 'post_author', array(
			'default' => 0,
			'type' => 'option',
			'sanitize_callback' => 'sanitize_checkbox',
		) );
		 
		$wp_customize->add_control( 'post_author', array(
			'label' => __('Display an author-box','og-zwanzig'),
			'type' => 'checkbox',
			'priority' => '2',
			'section' => 'ZWANZIG_posts',
		) );

		$wp_customize->add_setting( 'post_recommendation', array(
			'default' => 0,
			'type' => 'option',
			'sanitize_callback' => 'sanitize_checkbox',
		) );
		 
		$wp_customize->add_control( 'post_recommendation', array(
			'label' => __('Display post-recommendations','og-zwanzig'),
			'type' => 'checkbox',
			'priority' => '3',
			'section' => 'ZWANZIG_posts',
		) );

		$wp_customize->add_setting( 'post_recommendation_title', array(
			'type' => 'option',
			'sanitize_callback' => 'sanitize_text',
		) );

		$wp_customize->add_control( 'post_recommendation_title', array(
			'label' => __('Heading for the post-recommendation','og-zwanzig'),
			'type' => 'text',
			'priority' => '4',
			'section' => 'ZWANZIG_posts',
		) );

		$wp_customize->add_setting( 'post_navigation', array(
			'default' => 0,
			'type' => 'option',
			'sanitize_callback' => 'sanitize_checkbox',
		) );
		 
		$wp_customize->add_control( 'post_navigation', array(
			'label' => __('Display post-navigation','og-zwanzig'),
			'type' => 'checkbox',
			'priority' => '5',
			'section' => 'ZWANZIG_posts',
		) );



// ------------ add a section for post-share buttons ------------ //

	$wp_customize->add_section( 'ZWANZIG_share', array(
		'title' => __('ZWANZIG - Share buttons','og-zwanzig'),
		'priority' => '4'
	) );
	
	// add the settings and the controls

		$wp_customize->add_setting( 'post_share_title', array(
			'type' => 'option',
			'sanitize_callback' => 'sanitize_text',
		) );

		$wp_customize->add_control( 'post_share_title', array(
			'label' => __('Heading for the post-share-section','og-zwanzig'),
			'type' => 'text',
			'priority' => '1',
			'section' => 'ZWANZIG_share',
		) );

		$wp_customize->add_setting( 'share_google', array(
			'default' => 0,
			'type' => 'option',
			'sanitize_callback' => 'sanitize_checkbox',
		) );
		 
		$wp_customize->add_control( 'share_google', array(
			'label' => __('Google+1-button','og-zwanzig'),
			'type' => 'checkbox',
			'priority' => '2',
			'section' => 'ZWANZIG_share',
		) );

		$wp_customize->add_setting( 'share_facebook', array(
			'default' => 0,
			'type' => 'option',
			'sanitize_callback' => 'sanitize_checkbox',
		) );
		 
		$wp_customize->add_control( 'share_facebook', array(
			'label' => __('Facebook like-button','og-zwanzig'),
			'type' => 'checkbox',
			'priority' => '3',
			'section' => 'ZWANZIG_share',
		) );

		$wp_customize->add_setting( 'share_twitter', array(
			'default' => 0,
			'type' => 'option',
			'sanitize_callback' => 'sanitize_checkbox',
		) );
		 
		$wp_customize->add_control( 'share_twitter', array(
			'label' => __('Twitter tweet-button','og-zwanzig'),
			'type' => 'checkbox',
			'priority' => '4',
			'section' => 'ZWANZIG_share',
		) );

		$wp_customize->add_setting( 'share_pinterest', array(
			'default' => 0,
			'type' => 'option',
			'sanitize_callback' => 'sanitize_checkbox',
		) );
		 
		$wp_customize->add_control( 'share_pinterest', array(
			'label' => __('Pinterest Pin It-button','og-zwanzig'),
			'type' => 'checkbox',
			'priority' => '5',
			'section' => 'ZWANZIG_share',
		) );


// ------------ add a section for social network options ------------ //

	$wp_customize->add_section( 'ZWANZIG_social', array(
		'title' => __('ZWANZIG - Social Networks','og-zwanzig'),
		'priority' => '5'
	) );

	// add the settings and the controls

		$wp_customize->add_setting( 'facebook', array(
			'default' => 0,
			'type' => 'option',
			'sanitize_callback' => 'sanitize_checkbox',
		) );
		 
		$wp_customize->add_control( 'facebook', array(
			'label' => 'Facebook',
			'type' => 'checkbox',
			'section' => 'ZWANZIG_social',
			'priority' => '1'
		) );

		$wp_customize->add_setting( 'facebook_url', array(
			'type' => 'option',
			'sanitize_callback' => 'sanitize_text',
		) );

		$wp_customize->add_control( 'facebook_url', array(
			'label' => __('Link to your Facebook profile','og-zwanzig'),
			'type' => 'text',
			'section' => 'ZWANZIG_social',
			'priority' => '2'
		) );

		$wp_customize->add_setting( 'facebook_tooltip', array(
			'type' => 'option',
			'sanitize_callback' => 'sanitize_text',
		) );

		$wp_customize->add_control( 'facebook_tooltip', array(
			'label' => __('Facebook tooltip-text','og-zwanzig'),
			'type' => 'text',
			'section' => 'ZWANZIG_social',
			'priority' => '3'
		) );

		$wp_customize->add_setting( 'twitter', array(
			'default' => 0,
			'type' => 'option',
			'sanitize_callback' => 'sanitize_checkbox',
		) );
		 
		$wp_customize->add_control( 'twitter', array(
			'label' => 'Twitter',
			'type' => 'checkbox',
			'section' => 'ZWANZIG_social',
			'priority' => '4'
		) );

		$wp_customize->add_setting( 'twitter_url', array(
			'type' => 'option',
			'sanitize_callback' => 'sanitize_text',
		) );

		$wp_customize->add_control( 'twitter_url', array(
			'label' => __('Link to your Twitter profile','og-zwanzig'),
			'type' => 'text',
			'section' => 'ZWANZIG_social',
			'priority' => '5'
		) );

		$wp_customize->add_setting( 'twitter_tooltip', array(
			'type' => 'option',
			'sanitize_callback' => 'sanitize_text',
		) );

		$wp_customize->add_control( 'twitter_tooltip', array(
			'label' => __('Twitter tooltip-text','og-zwanzig'),
			'type' => 'text',
			'section' => 'ZWANZIG_social',
			'priority' => '6'
		) );

		$wp_customize->add_setting( 'google', array(
			'default' => 0,
			'type' => 'option',
			'sanitize_callback' => 'sanitize_checkbox',
		) );
		 
		$wp_customize->add_control( 'google', array(
			'label' => 'Google+',
			'type' => 'checkbox',
			'section' => 'ZWANZIG_social',
			'priority' => '7'
		) );

		$wp_customize->add_setting( 'google_url', array(
			'type' => 'option',
			'sanitize_callback' => 'sanitize_text',
		) );

		$wp_customize->add_control( 'google_url', array(
			'label' => __('Link to your Google+ profile','og-zwanzig'),
			'type' => 'text',
			'section' => 'ZWANZIG_social',
			'priority' => '8'
		) );

		$wp_customize->add_setting( 'google_tooltip', array(
			'type' => 'option',
			'sanitize_callback' => 'sanitize_text',
		) );

		$wp_customize->add_control( 'google_tooltip', array(
			'label' => __('Google+ tooltip-text','og-zwanzig'),
			'type' => 'text',
			'section' => 'ZWANZIG_social',
			'priority' => '9'
		) );

		$wp_customize->add_setting( 'vimeo', array(
			'default' => 0,
			'type' => 'option',
			'sanitize_callback' => 'sanitize_checkbox',
		) );
		 
		$wp_customize->add_control( 'vimeo', array(
			'label' => 'Vimeo',
			'type' => 'checkbox',
			'section' => 'ZWANZIG_social',
			'priority' => '10'
		) );

		$wp_customize->add_setting( 'vimeo_url', array(
			'type' => 'option',
			'sanitize_callback' => 'sanitize_text',
		) );

		$wp_customize->add_control( 'vimeo_url', array(
			'label' => __('Link to your Vimeo profile','og-zwanzig'),
			'type' => 'text',
			'section' => 'ZWANZIG_social',
			'priority' => '11'
		) );

		$wp_customize->add_setting( 'vimeo_tooltip', array(
			'type' => 'option',
			'sanitize_callback' => 'sanitize_text',
		) );

		$wp_customize->add_control( 'vimeo_tooltip', array(
			'label' => __('Vimeo tooltip-text','og-zwanzig'),
			'type' => 'text',
			'section' => 'ZWANZIG_social',
			'priority' => '12'
		) );

		$wp_customize->add_setting( 'twitch', array(
			'default' => 0,
			'type' => 'option',
			'sanitize_callback' => 'sanitize_checkbox',
		) );
		 
		$wp_customize->add_control( 'twitch', array(
			'label' => 'Twitch',
			'type' => 'checkbox',
			'section' => 'ZWANZIG_social',
			'priority' => '13'
		) );

		$wp_customize->add_setting( 'twitch_url', array(
			'type' => 'option',
			'sanitize_callback' => 'sanitize_text',
		) );

		$wp_customize->add_control( 'twitch_url', array(
			'label' => __('Link to your Twitch profile','og-zwanzig'),
			'type' => 'text',
			'section' => 'ZWANZIG_social',
			'priority' => '14'
		) );

		$wp_customize->add_setting( 'twitch_tooltip', array(
			'type' => 'option',
			'sanitize_callback' => 'sanitize_text',
		) );

		$wp_customize->add_control( 'twitch_tooltip', array(
			'label' => __('Twitch tooltip-text','og-zwanzig'),
			'type' => 'text',
			'section' => 'ZWANZIG_social',
			'priority' => '15'
		) );

		$wp_customize->add_setting( 'pinterest', array(
			'default' => 0,
			'type' => 'option',
			'sanitize_callback' => 'sanitize_checkbox',
		) );
		 
		$wp_customize->add_control( 'pinterest', array(
			'label' => 'Pinterest',
			'type' => 'checkbox',
			'section' => 'ZWANZIG_social',
			'priority' => '16'
		) );

		$wp_customize->add_setting( 'pinterest_url', array(
			'type' => 'option',
			'sanitize_callback' => 'sanitize_text',
		) );

		$wp_customize->add_control( 'pinterest_url', array(
			'label' => __('Link to your Pinterest profile','og-zwanzig'),
			'type' => 'text',
			'section' => 'ZWANZIG_social',
			'priority' => '17'
		) );

		$wp_customize->add_setting( 'pinterest_tooltip', array(
			'type' => 'option',
			'sanitize_callback' => 'sanitize_text',
		) );

		$wp_customize->add_control( 'pinterest_tooltip', array(
			'label' => __('Pinterest tooltip-text','og-zwanzig'),
			'type' => 'text',
			'section' => 'ZWANZIG_social',
			'priority' => '18'
		) );

		$wp_customize->add_setting( 'tumblr', array(
			'default' => 0,
			'type' => 'option',
			'sanitize_callback' => 'sanitize_checkbox',
		) );
		 
		$wp_customize->add_control( 'tumblr', array(
			'label' => 'Tumblr',
			'type' => 'checkbox',
			'section' => 'ZWANZIG_social',
			'priority' => '19'
		) );

		$wp_customize->add_setting( 'tumblr_url', array(
			'type' => 'option',
			'sanitize_callback' => 'sanitize_text',
		) );

		$wp_customize->add_control( 'tumblr_url', array(
			'label' => __('Link to your Tumblr profile','og-zwanzig'),
			'type' => 'text',
			'section' => 'ZWANZIG_social',
			'priority' => '20'
		) );

		$wp_customize->add_setting( 'tumblr_tooltip', array(
			'type' => 'option',
			'sanitize_callback' => 'sanitize_text',
		) );

		$wp_customize->add_control( 'tumblr_tooltip', array(
			'label' => __('Tumblr tooltip-text','og-zwanzig'),
			'type' => 'text',
			'section' => 'ZWANZIG_social',
			'priority' => '21'
		) );

		$wp_customize->add_setting( 'instagram', array(
			'default' => 0,
			'type' => 'option',
			'sanitize_callback' => 'sanitize_checkbox',
		) );
		 
		$wp_customize->add_control( 'instagram', array(
			'label' => 'Instagram',
			'type' => 'checkbox',
			'section' => 'ZWANZIG_social',
			'priority' => '22'
		) );

		$wp_customize->add_setting( 'instagram_url', array(
			'type' => 'option',
			'sanitize_callback' => 'sanitize_text',
		) );

		$wp_customize->add_control( 'instagram_url', array(
			'label' => __('Link to your Instagram profile','og-zwanzig'),
			'type' => 'text',
			'section' => 'ZWANZIG_social',
			'priority' => '23'
		) );

		$wp_customize->add_setting( 'instagram_tooltip', array(
			'type' => 'option',
			'sanitize_callback' => 'sanitize_text',
		) );

		$wp_customize->add_control( 'instagram_tooltip', array(
			'label' => __('Instagram tooltip-text','og-zwanzig'),
			'type' => 'text',
			'section' => 'ZWANZIG_social',
			'priority' => '24'
		) );

		$wp_customize->add_setting( 'flickr', array(
			'default' => 0,
			'type' => 'option',
			'sanitize_callback' => 'sanitize_checkbox',
		) );
		 
		$wp_customize->add_control( 'flickr', array(
			'label' => 'Flickr',
			'type' => 'checkbox',
			'section' => 'ZWANZIG_social',
			'priority' => '25'
		) );

		$wp_customize->add_setting( 'flickr_url', array(
			'type' => 'option',
			'sanitize_callback' => 'sanitize_text',
		) );

		$wp_customize->add_control( 'flickr_url', array(
			'label' => __('Link to your Flickr profile','og-zwanzig'),
			'type' => 'text',
			'section' => 'ZWANZIG_social',
			'priority' => '26'
		) );

		$wp_customize->add_setting( 'flickr_tooltip', array(
			'type' => 'option',
			'sanitize_callback' => 'sanitize_text',
		) );

		$wp_customize->add_control( 'flickr_tooltip', array(
			'label' => __('Flickr tooltip-text','og-zwanzig'),
			'type' => 'text',
			'section' => 'ZWANZIG_social',
			'priority' => '27'
		) );

		$wp_customize->add_setting( 'linkedin', array(
			'default' => 0,
			'type' => 'option',
			'sanitize_callback' => 'sanitize_checkbox',
		) );
		 
		$wp_customize->add_control( 'linkedin', array(
			'label' => 'Linkedin',
			'type' => 'checkbox',
			'section' => 'ZWANZIG_social',
			'priority' => '28'
		) );

		$wp_customize->add_setting( 'linkedin_url', array(
			'type' => 'option',
			'sanitize_callback' => 'sanitize_text',
		) );

		$wp_customize->add_control( 'linkedin_url', array(
			'label' => __('Link to your Linkedin profile','og-zwanzig'),
			'type' => 'text',
			'section' => 'ZWANZIG_social',
			'priority' => '29'
		) );

		$wp_customize->add_setting( 'linkedin_tooltip', array(
			'type' => 'option',
			'sanitize_callback' => 'sanitize_text',
		) );

		$wp_customize->add_control( 'linkedin_tooltip', array(
			'label' => __('Linkedin tooltip-text','og-zwanzig'),
			'type' => 'text',
			'section' => 'ZWANZIG_social',
			'priority' => '30'
		) );

		$wp_customize->add_setting( 'youtube', array(
			'default' => 0,
			'type' => 'option',
			'sanitize_callback' => 'sanitize_checkbox',
		) );
		 
		$wp_customize->add_control( 'youtube', array(
			'label' => 'YouTube',
			'type' => 'checkbox',
			'section' => 'ZWANZIG_social',
			'priority' => '31'
		) );

		$wp_customize->add_setting( 'youtube_url', array(
			'type' => 'option',
			'sanitize_callback' => 'sanitize_text',
		) );

		$wp_customize->add_control( 'youtube_url', array(
			'label' => __('Link to your YouTube profile','og-zwanzig'),
			'type' => 'text',
			'section' => 'ZWANZIG_social',
			'priority' => '32'
		) );

		$wp_customize->add_setting( 'youtube_tooltip', array(
			'type' => 'option',
			'sanitize_callback' => 'sanitize_text',
		) );

		$wp_customize->add_control( 'youtube_tooltip', array(
			'label' => __('YouTube tooltip-text','og-zwanzig'),
			'type' => 'text',
			'section' => 'ZWANZIG_social',
			'priority' => '33'
		) );

		$wp_customize->add_setting( 'spotify', array(
			'default' => 0,
			'type' => 'option',
			'sanitize_callback' => 'sanitize_checkbox',
		) );
		 
		$wp_customize->add_control( 'spotify', array(
			'label' => 'Spotify',
			'type' => 'checkbox',
			'section' => 'ZWANZIG_social',
			'priority' => '34'
		) );

		$wp_customize->add_setting( 'spotify_url', array(
			'type' => 'option',
			'sanitize_callback' => 'sanitize_text',
		) );

		$wp_customize->add_control( 'spotify_url', array(
			'label' => __('Link to your Spotify profile','og-zwanzig'),
			'type' => 'text',
			'section' => 'ZWANZIG_social',
			'priority' => '35'
		) );

		$wp_customize->add_setting( 'spotify_tooltip', array(
			'type' => 'option',
			'sanitize_callback' => 'sanitize_text',
		) );

		$wp_customize->add_control( 'spotify_tooltip', array(
			'label' => __('Spotify tooltip-text','og-zwanzig'),
			'type' => 'text',
			'section' => 'ZWANZIG_social',
			'priority' => '36'
		) );
		$wp_customize->add_setting( 'rss', array(
			'default' => 0,
			'type' => 'option',
			'sanitize_callback' => 'sanitize_checkbox',
		) );
		 
		$wp_customize->add_control( 'rss', array(
			'label' => __('RSS-Feed','og-zwanzig'),
			'type' => 'checkbox',
			'section' => 'ZWANZIG_social',
			'priority' => '37'
		) );

		$wp_customize->add_setting( 'rss_tooltip', array(
			'type' => 'option',
			'sanitize_callback' => 'sanitize_text',
		) );

		$wp_customize->add_control( 'rss_tooltip', array(
			'label' => __('RSS-Feed tooltip-text','og-zwanzig'),
			'type' => 'text',
			'section' => 'ZWANZIG_social',
			'priority' => '38'
		) );



// ------------ add settings and controls for theme-colors ------------ //

	$wp_customize->add_setting( 'default_color', array(
		'default' => '#1e5078',
		'type' => 'option',
		'sanitize_callback'    => 'sanitize_hex_color_no_hash',
		'sanitize_js_callback' => 'maybe_hash_hex_color',
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'default_color', array(
		'label'   => __('Default color','og-zwanzig'),
		'section' => 'colors',
		'priority' => '1'
	) ) );

	$wp_customize->add_setting( 'akzent_color', array(
		'default' => '#113b63',
		'type' => 'option',
		'sanitize_callback'    => 'sanitize_hex_color_no_hash',
		'sanitize_js_callback' => 'maybe_hash_hex_color',
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'akzent_color', array(
		'label'   => __('Akzent color','og-zwanzig'),
		'section' => 'colors',
		'priority' => '2'
	) ) );

	$wp_customize->add_setting( 'alternate_color', array(
		'default' => '#21ade0',
		'type' => 'option',
		'sanitize_callback'    => 'sanitize_hex_color_no_hash',
		'sanitize_js_callback' => 'maybe_hash_hex_color',
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'alternate_color', array(
		'label'   => __('Alternate color','og-zwanzig'),
		'section' => 'colors',
		'priority' => '3'
	) ) );

	$wp_customize->add_setting( 'sidebar_color', array(
		'default' => '#2a2a2a',
		'type' => 'option',
		'sanitize_callback'    => 'sanitize_hex_color_no_hash',
		'sanitize_js_callback' => 'maybe_hash_hex_color',
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'sidebar_color', array(
		'label'   => __('Sidebar color','og-zwanzig'),
		'section' => 'colors',
		'priority' => '4'
	) ) );

	$wp_customize->add_setting( 'contrast_color', array(
		'default' => '#f2f2f2',
		'type' => 'option',
		'sanitize_callback'    => 'sanitize_hex_color_no_hash',
		'sanitize_js_callback' => 'maybe_hash_hex_color',
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'contrast_color', array(
		'label'   => __('Contrast color','og-zwanzig'),
		'section' => 'colors',
		'priority' => '4'
	) ) );

	$wp_customize->add_setting( 'default_font_color', array(
		'default' => '#222222',
		'type' => 'option',
		'sanitize_callback'    => 'sanitize_hex_color_no_hash',
		'sanitize_js_callback' => 'maybe_hash_hex_color',
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'default_font_color', array(
		'label'   => __('Font color','og-zwanzig'),
		'section' => 'colors',
		'priority' => '8'
	) ) );

	$wp_customize->add_setting( 'link_color', array(
		'default' => '#113b63',
		'type' => 'option',
		'sanitize_callback'    => 'sanitize_hex_color_no_hash',
		'sanitize_js_callback' => 'maybe_hash_hex_color',
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'link_color', array(
		'label'   => __('Hyperlink color','og-zwanzig'),
		'section' => 'colors',
		'priority' => '9'
	) ) );

	$wp_customize->add_setting( 'hover_color', array(
		'default' => '#21ade0',
		'type' => 'option',
		'sanitize_callback'    => 'sanitize_hex_color_no_hash',
		'sanitize_js_callback' => 'maybe_hash_hex_color',
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'hover_color', array(
		'label'   => __('Hover color','og-zwanzig'),
		'section' => 'colors',
		'priority' => '9'
	) ) );



// ------------ add settings and controls for title and tagline ------------ //

	$wp_customize->add_setting( 'bloginfo', array(
		'default' => '0',
		'type' => 'option',
		'sanitize_callback' => 'sanitize_bloginfo',
	) );
	 
	$wp_customize->add_control( 'bloginfo', array(
		'label' => __('Display title and/or tagline','og-zwanzig'),
		'section' => 'title_tagline',
		'type' => 'select',
		'choices' => array(
			'0' => __('none','og-zwanzig'),
			'1' => __('Site Title','og-zwanzig'),
			'2' => __('Tagline','og-zwanzig'),
			'3' => __('Site Title and Tagline','og-zwanzig'),
		),
	) );

	function sanitize_bloginfo( $input ) {
		$valid = array(
		'0' => __('none','og-zwanzig'),
		'1' => __('Site Title','og-zwanzig'),
		'2' => __('Tagline','og-zwanzig'),
		'3' => __('Site Title and Tagline','og-zwanzig'),
		);
 
		if ( array_key_exists( $input, $valid ) ) {
			return $input;
		} else {
			return '';
		}
	}

	$wp_customize->add_setting( 'bloginfo_home', array(
		'type' => 'option',
		'sanitize_callback' => 'sanitize_checkbox',
	) );
		 
	$wp_customize->add_control( 'bloginfo_home', array(
		'label' => __('Display the title and/or tagline only on the frontpage','og-zwanzig'),
		'type' => 'checkbox',
		'priority' => '2',
		'section' => 'title_tagline',
	) );


}



// ------------ add a textarea-control for theme-customizing ------------ //

if( class_exists( 'WP_Customize_Control' ) ):
	class WP_Customize_Textarea_Control extends WP_Customize_Control {
		public $type = 'textarea';
 
		public function render_content() {
			?>
		<label>
			<span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
			<textarea rows="10" style="width:100%;" <?php $this->link(); ?>><?php echo esc_textarea( $this->value() ); ?></textarea>
		</label>
		<?php
		}
	}
endif;



// ------------ Sanitize functions for the customizer options ------------ //

function sanitize_text( $input ) {
    return wp_kses_post( force_balance_tags( $input ) );
}

function sanitize_checkbox( $input ) {
    if ( $input == 1 ) {
        return 1;
    } else {
        return '';
    }
}

add_action('admin_init','optionscheck_change_santiziation', 100);
 
function optionscheck_change_santiziation() {
    remove_filter( 'of_sanitize_textarea', 'of_sanitize_textarea' );
    add_filter( 'of_sanitize_textarea', 'custom_sanitize_textarea' );
}
 
function custom_sanitize_textarea($input) {

	global $allowedposttags;

	$custom_allowedtags["link"] = array(
	      "href" => array(),
	      "rel" => array(),
	      "type" => array(),
	);

	$custom_allowedtags["script"] = array(
	      "script" => array(),
	);
 
	$custom_allowedtags = array_merge($custom_allowedtags, $allowedposttags);
	$output = wp_kses( $input, $custom_allowedtags);
return $output;

}



// ------------ Output custom CSS to live site ------------ //

function og_customize_css()

{
    ?>		

		<?php if ( get_option('font_standard') == 0 ) { ?>
			<link href='http://fonts.googleapis.com/css?family=Open+Sans:400,700' rel='stylesheet' type='text/css'>
		<?php } elseif ( get_option('font_standard') == 1 ) { ?>
			<link href='http://fonts.googleapis.com/css?family=Varela+Round' rel='stylesheet' type='text/css'>
		<?php } elseif ( get_option('font_standard') == 2 ) { ?>
			<link href='http://fonts.googleapis.com/css?family=Source+Sans+Pro:400,700' rel='stylesheet' type='text/css'>
		<?php } elseif ( get_option('font_standard') == 3 ) { ?>
			<link href='http://fonts.googleapis.com/css?family=PT+Sans:400,700' rel='stylesheet' type='text/css'>
		<?php } elseif ( get_option('font_standard') == 4 ) { ?>
			<link href='http://fonts.googleapis.com/css?family=Ubuntu:400,700' rel='stylesheet' type='text/css'>
		<?php } elseif ( get_option('font_standard') == 5 ) { ?>
			<link href='http://fonts.googleapis.com/css?family=Roboto:400,700' rel='stylesheet' type='text/css'>
		<?php } elseif ( get_option('font_standard') == 6 ) { ?>
			<link href='http://fonts.googleapis.com/css?family=Noto+Sans:400,700' rel='stylesheet' type='text/css'>
		<?php } elseif ( get_option('font_standard') == 7 ) { ?>
			<link href='http://fonts.googleapis.com/css?family=Noto+Serif:400,700' rel='stylesheet' type='text/css'>
		<?php } elseif ( get_option('font_standard') == 12 ) { ?>
			<?php echo get_option('font_standard_html'); ?>
		<?php } ?>

		<?php if ( get_option('font_h') == 0 ) { ?>
			<link href='http://fonts.googleapis.com/css?family=Open+Sans+Condensed:400,700' rel='stylesheet' type='text/css'>
		<?php } elseif ( get_option('font_h') == 1 ) { ?>
			<link href='http://fonts.googleapis.com/css?family=Fjalla+One' rel='stylesheet' type='text/css'>
		<?php } elseif ( get_option('font_h') == 2 ) { ?>
			<link href='http://fonts.googleapis.com/css?family=Raleway:400,700' rel='stylesheet' type='text/css'>
		<?php } elseif ( get_option('font_h') == 3 ) { ?>
			<link href='http://fonts.googleapis.com/css?family=Montserrat:400,700' rel='stylesheet' type='text/css'>
		<?php } elseif ( get_option('font_h') == 4 ) { ?>
			<link href='http://fonts.googleapis.com/css?family=Open+Sans:300' rel='stylesheet' type='text/css'>
		<?php } elseif ( get_option('font_h') == 5 ) { ?>
			<link href='http://fonts.googleapis.com/css?family=Bitter:700' rel='stylesheet' type='text/css'>
		<?php } elseif ( get_option('font_h') == 6 ) { ?>
			<link href='http://fonts.googleapis.com/css?family=Bree+Serif' rel='stylesheet' type='text/css'>
		<?php } elseif ( get_option('font_h') == 7 ) { ?>
			<link href='http://fonts.googleapis.com/css?family=Francois+One' rel='stylesheet' type='text/css'>
		<?php } elseif ( get_option('font_h') == 8 ) { ?>
			<link href='http://fonts.googleapis.com/css?family=Lato:400,700' rel='stylesheet' type='text/css'>
		<?php } elseif ( get_option('font_h') == 13 ) { ?>
			<?php echo get_option('font_h_html'); ?>
		<?php } ?>

         <style type="text/css">

	<?php if ( get_option('sidebar_alignment') == 1 ) { ?>

		.sidebar-blog {
			float: right;
		}

	<?php } ?>

	<?php if ( get_option('header_slider_responsive') == 1 ) { ?>

		@media screen and (max-width: 600px) {

		.header-slider {
			display: none;
		}

		}

	<?php } ?>

	<?php if ( get_option('header_slider_time') ) { ?>

		.header-slider {
			-webkit-animation-duration: <?php echo get_option('header_slider_time','30'); ?>s; 
			-moz-animation-duration: <?php echo get_option('header_slider_time','30'); ?>s;  
			-o-animation-duration: <?php echo get_option('header_slider_time','30'); ?>s;  
			-ms-animation-duration: <?php echo get_option('header_slider_time','30'); ?>s;  
			animation-duration: <?php echo get_option('header_slider_time','30'); ?>s;  
		}

		.header-slider .slider-progressbar {
			-webkit-animation-duration: <?php echo get_option('header_slider_time','30'); ?>s; 
			-moz-animation-duration: <?php echo get_option('header_slider_time','30'); ?>s;  
			-o-animation-duration: <?php echo get_option('header_slider_time','30'); ?>s;  
			-ms-animation-duration: <?php echo get_option('header_slider_time','30'); ?>s;  
			animation-duration: <?php echo get_option('header_slider_time','30'); ?>s;  
		}

	<?php } ?>

	<?php if ( get_option('header_slider_border') == 1 ) { ?>

		.slider-post {
			padding: 10px;
			background: #fff;
		}

	<?php } ?>

	<?php if ( get_option('header_slider_reverse') == 1 ) { ?>

		.header-slider {
			-webkit-animation-direction: reverse; 
			-moz-animation-direction: reverse;  
			-o-animation-direction: reverse;  
			-ms-animation-direction: reverse;  
			animation-direction: reverse;  
		}

		.header-slider .slider-progressbar {
			-webkit-animation-direction: reverse; 
			-moz-animation-direction: reverse;  
			-o-animation-direction: reverse;  
			-ms-animation-direction: reverse;  
			animation-direction: reverse;  
		}

	<?php } ?>

	<?php if ( get_option('navigation_open') == 1 ) { ?>

		#content,
		.header-content,
		.menu-bar {
			top: 60px;
		}

		#content {
			margin-bottom: 60px;
		}

		input#top-bar-navigation[type=checkbox]:checked ~ #content,
		input#top-bar-navigation[type=checkbox]:checked ~ .header-content,
		input#top-bar-navigation[type=checkbox]:checked ~ .menu-bar,
		input#top-bar-navigation[type=checkbox]:checked ~ footer.side-footer {
			top: 0;
		}

		input#top-bar-navigation[type=checkbox]:checked ~ #content {
			margin-bottom: 0;
		}

		input#top-bar-navigation[type=checkbox]:checked ~ label.top-bar-navigation-label .genericon {
			background: none !important;
		}

		input#top-bar-navigation[type=checkbox]:checked ~ label.top-bar-navigation-label:hover .genericon,
		label.top-bar-navigation-label:hover .genericon,
		label.top-bar-navigation-label .genericon {
			background-color: #<?php echo get_option('alternate_color','21ade0'); ?> !important;
		}


	<?php } ?>

		body { font-size: <?php echo get_option('font_size', '14px'); ?>; }

		body, 
		input, 
		select, 
		textarea,
		a#cancel-comment-reply-link { 
		<?php if ( get_option('font_standard') == 0 ) { ?>
			font-family: 'Open Sans', sans-serif;
		<?php } elseif ( get_option('font_standard') == 1 ) { ?>
			font-family: 'Varela Round', sans-serif;
		<?php } elseif ( get_option('font_standard') == 2 ) { ?>
			font-family: 'Source Sans Pro', sans-serif;
		<?php } elseif ( get_option('font_standard') == 3 ) { ?>
			font-family: 'PT Sans', sans-serif;
		<?php } elseif ( get_option('font_standard') == 4 ) { ?>
			font-family: 'Ubuntu', sans-serif;
		<?php } elseif ( get_option('font_standard') == 5 ) { ?>
			font-family: 'Roboto', sans-serif;
		<?php } elseif ( get_option('font_standard') == 6 ) { ?>
			font-family: 'Noto Sans', sans-serif;
		<?php } elseif ( get_option('font_standard') == 7 ) { ?>
			font-family: 'Noto Serif', serif;
		<?php } elseif ( get_option('font_standard') == 8 ) { ?>
			font-family: 'Arial', sans-serif;
		<?php } elseif ( get_option('font_standard') == 9 ) { ?>
			font-family: 'Verdana', sans-serif;
		<?php } elseif ( get_option('font_standard') == 10 ) { ?>
			font-family: 'Tahoma', sans-serif;
		<?php } elseif ( get_option('font_standard') == 11 ) { ?>
			font-family: 'Lucida Sans', sans-serif;
		<?php } elseif ( get_option('font_standard') == 11 ) { ?>
			font-family: 'Georgia', serif;
		<?php } elseif ( get_option('font_standard') == 13 ) { ?>
			<?php echo get_option('font_standard_css'); ?> 
		<?php } ?>
		}

		h1, 
		h2, 
		h3, 
		h4, 
		h5, 
		h6,
		.post-navigation a,
		a.more-link,
		input[type="submit"],
		.button a,
		.commentlist li .comment-author,
		nav.top-nav,
		nav.footer-nav,
		#respond .comment-form p label { 
		<?php if ( get_option('font_h') == 0 ) { ?>
			font-family: 'Open Sans Condensed', sans-serif;
		<?php } elseif ( get_option('font_h') == 1 ) { ?>
			font-family: 'Fjalla One', sans-serif; font-weight: normal !important;
		<?php } elseif ( get_option('font_h') == 2 ) { ?>
			font-family: 'Raleway', sans-serif;
		<?php } elseif ( get_option('font_h') == 3 ) { ?>
			font-family: 'Montserrat', sans-serif;
		<?php } elseif ( get_option('font_h') == 4 ) { ?>
			font-family: 'Open Sans', sans-serif; font-weight: 300 !important;
		<?php } elseif ( get_option('font_h') == 5 ) { ?>
			font-family: 'Bitter', serif;
		<?php } elseif ( get_option('font_h') == 6 ) { ?>
			font-family: 'Bree Serif', serif; font-weight: normal !important;
		<?php } elseif ( get_option('font_h') == 7 ) { ?>
			font-family: 'Francois One', sans-serif; font-weight: normal !important;
		<?php } elseif ( get_option('font_h') == 8 ) { ?>
			font-family: 'Lato', sans-serif;
		<?php } elseif ( get_option('font_h') == 9 ) { ?>
			font-family: 'Arial', sans-serif;
		<?php } elseif ( get_option('font_h') == 10 ) { ?>
			font-family: 'Verdana', sans-serif;
		<?php } elseif ( get_option('font_h') == 11 ) { ?>
			font-family: 'Tahoma', sans-serif;
		<?php } elseif ( get_option('font_h') == 12 ) { ?>
			font-family: 'Lucida Sans', sans-serif;
		<?php } elseif ( get_option('font_h') == 13 ) { ?>
			<?php echo get_option('font_h_css'); ?> 
		<?php } ?>
		}

		body,
		h6,
		nav.top-nav li:hover li a,
		nav.top-nav li li > a:after,
		.post-navigation a p {
			color: #<?php echo get_option('default_font_color','222222'); ?>;
		}

		a { color: #<?php echo get_option('link_color','113b63'); ?>; }

		a:hover { color: #<?php echo get_option('hover_color','21ade0'); ?>; }

		.sticky:after,
		.wp-pagenavi a:hover,
		.search-archive label:hover,
		.search-archive input[type=checkbox]:checked ~ label,
		.search-archive a,
		a.scroll-top:hover,
		.comment-navigation a,
		a.more-link,
		.header-menu li a,
		.button a,
		input[type="submit"] { 
			background-color: #<?php echo get_option('default_color','1e5078'); ?>;
		}

		nav.top-nav > ul > li > a:hover,
		nav.top-nav > ul > li:hover > a,
		nav.top-nav > ul > li.current-menu-item > a,
		nav.top-nav > ul > li.current-menu-ancestor > a,
		.search-archive label,
		.search-archive a:hover,
		.comment-awaiting-moderation,
		h6.notice,
		#top-search .search-form #sb,
		.top-bar-social li:hover span,
		label.responsive-social-icons:hover .genericon,
		input#responsive-socialicons[type=checkbox]:checked ~ label.responsive-social-icons .genericon,
		label.header-search:hover .genericon,
		input#header-search[type=checkbox]:checked ~ label.header-search .genericon,
		label.top-bar-navigation-label:hover .genericon,
		input#top-bar-navigation[type=checkbox]:checked ~ label.top-bar-navigation-label .genericon,
		a.scroll-top,
		a#cancel-comment-reply-link:hover,
		a.comment-reply-link:hover,
		a.more-link:hover,
		.post-edit a:hover,
		.comment-navigation a:hover,
		.button a:hover,
		input[type="submit"]:hover,
		.wp-pagenavi span.current { 
			background-color: #<?php echo get_option('alternate_color','21ade0'); ?>;
		}

		#top-search .search-form #sb:hover,
		a.comment-reply-link,
		a#cancel-comment-reply-link { 
			background-color: #<?php echo get_option('akzent_color','113b63'); ?>;
		}

		#content { 
			background-color: #<?php echo get_option('sidebar_color','2a2a2a'); ?>;
		}

		.gallery,
		.comment-meta,
		.comment-content,
		.author-info,
		.post-share,
		.wpcf7 form,
		.wp-pagenavi a,
		.wp-pagenavi span,
		#respond,
		.search-archive ul,
		pre,
		blockquote,
		code,
		.post-navigation a { 
			background-color: #<?php echo get_option('contrast_color','f2f2f2'); ?>;
		}

		h1 { 
			color: #<?php echo get_option('default_color','1e5078'); ?>;
		}

		nav.top-nav li li:hover > a,
		nav.top-nav li li:hover > a:after,
		nav.top-nav ul ul li.current-menu-item > a,
		nav.top-nav ul ul li.current-menu-ancestor > a,
		nav.top-nav ul ul li.current-menu-ancestor > a:after,
		nav.top-nav ul ul li ul .current-menu-item > a,
		nav.top-nav ul ul li ul .current-menu-ancestor > a,
		.entry span,
		h3 { 
			color: #<?php echo get_option('alternate_color','21ade0'); ?>;
		}

		h5,
		.genericon.small { 
			color: #<?php echo get_option('akzent_color','113b63'); ?>;
		}

		input[type="submit"],
		a.more-link {
			border-color: #<?php echo get_option('alternate_color','21ade0'); ?>;
		}

		li.bypostauthor > article .comment-meta { 
			border-top-color: #<?php echo get_option('alternate_color','21ade0'); ?>;
		}

		.commentlist li:before {
			border-right-color: #<?php echo get_option('contrast_color','f2f2f2'); ?>;
		}

         </style>

    <?php
}
add_action( 'wp_head', 'og_customize_css');



// ------------ Setup the Theme Customizer settings and controls ------------ //

add_action( 'customize_register', 'og_theme_customizer' );



// ------------ add an theme-based stylesheet for TinyMCE ------------ //

add_editor_style();



// ------------ use HTML5-Markup ------------ //

add_theme_support( 'html5', array( 'comment-list', 'comment-form', 'search-form', 'gallery', 'caption' ) 
);



// ------------ activate the custom-background-function and set the default background ------------ //

add_theme_support( 'custom-background', array( 'default-color' => '#757575' ) );



// ------------ activate the custom-header-function ------------ //

$defaults = array(
	'random-default'         => false,
	'width'                  => 1200,
	'height'                 => 300,
	'flex-height'            => false,
	'flex-width'             => false,
	'header-text'            => false,
	'uploads'                => true,
);

add_theme_support( 'custom-header', $defaults );



// ------------ activate the post-thumbnail-function and set the sizes ------------ //

if ( function_exists('add_theme_support') ) {
add_theme_support( 'post-thumbnails', array('post') );

	set_post_thumbnail_size(840, 200, true);
	add_image_size( 'slider-thumbnail', 1200, 300, true ); 
	add_image_size( 'recommendation-thumbnail', 250, 150, true ); 
	add_image_size( 'archive-thumbnail', 365, 150, true ); 
}



// ------------ show post-thumbnails in the list of posts in the backend if function is enabled ------------ //

if ( !function_exists('fb_AddThumbColumn') && function_exists('add_theme_support') ) {
add_theme_support('post-thumbnails', array( 'post', 'page' ) );

	function fb_AddThumbColumn($cols) {
       		$cols['thumbnail'] = ('Thumbnail');
	        return $cols;
	}

	function fb_AddThumbValue($column_name, $post_id) {

	            $width = (int) 35;
        	    $height = (int) 35;

	            if ( 'thumbnail' == $column_name ) {
        	        // thumbnail of WP 2.9
                	$thumbnail_id = get_post_meta( $post_id, '_thumbnail_id', true );
	                // image from gallery
        	        $attachments = get_children( array('post_parent' => $post_id, 'post_type' => 'attachment', 'post_mime_type' => 'image') );
                	if ($thumbnail_id)
	                    $thumb = wp_get_attachment_image( $thumbnail_id, array($width, $height), true );
        	        elseif ($attachments) {
                	    foreach ( $attachments as $attachment_id => $attachment ) {
                        	$thumb = wp_get_attachment_image( $attachment_id, array($width, $height), true );
	                    }
        	        }
                	    if ( isset($thumb) && $thumb ) {
                        	echo $thumb;
	                    } else {
        	                echo ('None');
                	    }
	            }
   	}

	    add_filter( 'manage_posts_columns', 'fb_AddThumbColumn' );
	    add_action( 'manage_posts_custom_column', 'fb_AddThumbValue', 10, 2 );
}

				

// ------------ register the sidebar ------------ //

function sidebars_init() {

register_sidebar( array(
	'name' 		=> __( 'Sidebar aside','og-zwanzig' ),
	'description'   => __( 'Widgets in this area will be shown aside on all posts and pages, except the page-template without sidebar','og-zwanzig' ),
	'id' 		=> 'sidebar-blog',
	'before_title'  => '<h6 class="widgettitle">',
	'after_title'   => '</h6>'
	)
);

register_sidebar( array(
	'name' 		=> __( 'Sidebar bottom left','og-zwanzig' ),
	'description'   => __( 'Widgets in this area will be shown in the footer outside left','og-zwanzig' ),
	'id' 		=> 'sidebar-bottom-left',
	'before_title'  => '<h6 class="widgettitle">',
	'after_title'   => '</h6>'
	)
);

register_sidebar( array(
	'name' 		=> __( 'Sidebar bottom middle left','og-zwanzig' ),
	'description'   => __( 'Widgets in this area will be shown in the footer center-left','og-zwanzig' ),
	'id' 		=> 'sidebar-bottom-middle-left',
	'before_title'  => '<h6 class="widgettitle">',
	'after_title'   => '</h6>'
	)
);

register_sidebar( array(
	'name' 		=> __( 'Sidebar bottom middle right','og-zwanzig' ),
	'description'   => __( 'Widgets in this area will be shown in the footer center-right','og-zwanzig' ),
	'id' 		=> 'sidebar-bottom-middle-right',
	'before_title'  => '<h6 class="widgettitle">',
	'after_title'   => '</h6>'
	)
);

register_sidebar( array(
	'name' 		=> __( 'Sidebar bottom right','og-zwanzig' ),
	'description'   => __( 'Widgets in this area will be shown in the footer outside right','og-zwanzig' ),
	'id' 		=> 'sidebar-bottom-right',
	'before_title'  => '<h6 class="widgettitle">',
	'after_title'   => '</h6>'
	)
);

register_sidebar( array(
	'name' 		=> __( 'Sidebar for responsive layout','og-zwanzig' ),
	'description'   => __( 'Widgets in this area will only be shown when the responsive layout is active','og-zwanzig' ),
	'id' 		=> 'sidebar-responsive',
	'before_title'  => '<h6 class="widgettitle">',
	'after_title'   => '</h6>'
	)
);

}

add_action( 'widgets_init', 'sidebars_init' );



// ------------ register the nav-menus ------------ //

if ( function_exists('register_nav_menus') ) {
register_nav_menus( array(
	'top_bar_menu' => __( 'Top-bar navigation','og-zwanzig' ),
	'footer_menu' => __( 'Footer navigation (only 1st level)','og-zwanzig' ),
	)
);
}


// ------------ activate feed-link-support ------------ //

if ( function_exists('add_theme_support') ) {
add_theme_support('automatic-feed-links');
}



// ------------ set the maximum content width ------------ //

if ( ! isset( $content_width ) ) $content_width = 700;



// ------------ set the number of words for the post-excerpt ------------ //

function custom_excerpt_length( $length ) {

	if ( get_option( 'excerpt_words' ) ) { 
		return get_option( 'excerpt_words' );
	} else { 
		return 55;
	}
}

add_filter( 'excerpt_length', 'custom_excerpt_length', 999 );
 


// ------------ show a read-more-link for the excerpt ------------ //

if ( get_option( 'excerpt_moretag' ) == 1 ) {

	function new_excerpt_more($more) {
        	return '
			<a class="more-link" href="'.get_permalink().'">' . __('Continue reading','og-zwanzig') . '</a>';
	}

add_filter('excerpt_more', 'new_excerpt_more');

}



// ------------ set shortcodes for columns ------------ //

function twocolumns_shortcode( $atts, $content = null ) {
	return '<div class="two-columns">' . do_shortcode($content) . '</div>';
}
add_shortcode( 'two-columns', 'twocolumns_shortcode' );

function threecolumns_shortcode( $atts, $content = null ) {
	return '<div class="three-columns">' . do_shortcode($content) . '</div>';
}
add_shortcode( 'three-columns', 'threecolumns_shortcode' );

function fourcolumns_shortcode( $atts, $content = null ) {
	return '<div class="four-columns">' . do_shortcode($content) . '</div>';
}
add_shortcode( 'four-columns', 'fourcolumns_shortcode' );

function fivecolumns_shortcode( $atts, $content = null ) {
	return '<div class="five-columns">' . do_shortcode($content) . '</div>';
}
add_shortcode( 'five-columns', 'fivecolumns_shortcode' );



// ------------ set shortcodes for infoboxes ------------ //

function infobox_shortcode ( $atts, $content = null) {

extract( shortcode_atts( array(
      'color' => '', 
      'type' => '', 
      'border' => '', 
	   ), $atts ) );
      return '<div class="infobox ' . $color . ' ' . $border . ' ' . $type . '">'.do_shortcode($content).'</div>';

}
add_shortcode('infobox', 'infobox_shortcode');



// ------------ set shortcodes for buttons ------------ //

function button_shortcode ( $atts, $content = null) {

extract( shortcode_atts( array(
	'color'  => '', 
	'size'   => '', 
	'link'   => '',
	'align'  => '',
	'type'   => '',
	'target' => '',
	), $atts ) );

	$target = ($target == 'blank') ? ' target="_blank"' : '';

	return '<div class="button ' . $size . ' ' . $align . ' ' . $color . '"><a ' .$target. ' class="' . $type . '" href="' . $link . '">' . $content . '</a></div>';
}
add_shortcode('button', 'button_shortcode');



// ------------ delete the shortcodes from the excerpt ------------ //

function custom_excerpt($text = '') {
	$raw_excerpt = $text;
	if ( '' == $text ) {
		$text = get_the_content('');
                // $text = strip_shortcodes( $text );
		$text = do_shortcode( $text );
		$text = apply_filters('the_content', $text);
		$text = str_replace(']]>', ']]>', $text);
		$excerpt_length = apply_filters('excerpt_length', 55);
		$excerpt_more = apply_filters('excerpt_more', ' ' . '[...]');
		$text = wp_trim_words( $text, $excerpt_length, $excerpt_more );
	}
	return apply_filters('wp_trim_excerpt', $text, $raw_excerpt);
}
remove_filter( 'get_the_excerpt', 'wp_trim_excerpt'  );
add_filter( 'get_the_excerpt', 'custom_excerpt'  );

?>